Writer

Trait Writer 

pub trait Writer {
    // Required method
    fn write(&mut self, bytes: &[u8]) -> Result<(), EncodeError>;
}
Trait that indicates that a struct can be used as a destination to encode data too. This is used by Encode

Required Methods

fn write(&mut self, bytes: &[u8]) -> Result<(), EncodeError>

Write bytes to the underlying writer. Exactly bytes.len() bytes must be written, or else an error should be returned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: Writer> Writer for &mut T

Source

fn write(&mut self, bytes: &[u8]) -> Result<(), EncodeError>

Implementors